==> qtjambi-nfc-5.15.17-sources.jar: io/qt/nfc/QNearFieldShareTarget.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>Transfers data to remote device over NFC</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html">QNearFieldShareTarget</a></code></p>
 */
public final class QNearFieldShareTarget extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNearFieldShareTarget.class);
    

    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#error">QNearFieldShareTarget::<wbr>error(QNearFieldShareManager::ShareError)</a></code></p>
     */
    public final @NonNull Signal1<io.qt.nfc.QNearFieldShareManager.@NonNull ShareError> error = new Signal1<>();

    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareFinished">QNearFieldShareTarget::<wbr>shareFinished()</a></code></p>
     */
    public final @NonNull Signal0 shareFinished = new Signal0();
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#cancel">QNearFieldShareTarget::<wbr>cancel()</a></code></p>
     */
    @QtUninvokable
    public final void cancel(){
        cancel_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void cancel_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#isShareInProgress">QNearFieldShareTarget::<wbr>isShareInProgress()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isShareInProgress(){
        return isShareInProgress_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isShareInProgress_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#share-1">QNearFieldShareTarget::<wbr>share(QList&lt;QFileInfo&gt;)</a></code></p>
     */
    @QtUninvokable
    public final boolean share(java.util.@NonNull Collection<? extends io.qt.core.@NonNull QFileInfo> files){
        return share_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), files);
    }
    
    @QtUninvokable
    private native boolean share_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.core.QFileInfo> files);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#share">QNearFieldShareTarget::<wbr>share(QNdefMessage)</a></code></p>
     */
    @QtUninvokable
    public final boolean share(io.qt.nfc.@NonNull QNdefMessage message){
        return share_native_cref_QNdefMessage(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(message));
    }
    
    @QtUninvokable
    private native boolean share_native_cref_QNdefMessage(long __this__nativeId, long message);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareError">QNearFieldShareTarget::<wbr>shareError()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.nfc.QNearFieldShareManager.@NonNull ShareError shareError(){
        return io.qt.nfc.QNearFieldShareManager.ShareError.resolve(shareError_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int shareError_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareModes">QNearFieldShareTarget::<wbr>shareModes()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.nfc.QNearFieldShareManager.@NonNull ShareModes shareModes(){
        return new io.qt.nfc.QNearFieldShareManager.ShareModes(shareModes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int shareModes_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNearFieldShareTarget(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-nfc-5.15.19-sources.jar: io/qt/nfc/QNearFieldShareTarget.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>Transfers data to remote device over NFC</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html">QNearFieldShareTarget</a></code></p>
 */
public final class QNearFieldShareTarget extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QNearFieldShareTarget.class);
    

    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#error">QNearFieldShareTarget::<wbr/>error(QNearFieldShareManager::ShareError)</a></code></p>
     */
    public final @NonNull Signal1<io.qt.nfc.QNearFieldShareManager.@NonNull ShareError> error = new Signal1<>();

    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareFinished">QNearFieldShareTarget::<wbr/>shareFinished()</a></code></p>
     */
    public final @NonNull Signal0 shareFinished = new Signal0();
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#cancel">QNearFieldShareTarget::<wbr/>cancel()</a></code></p>
     */
    @QtUninvokable
    public final void cancel(){
        cancel_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void cancel_native(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#isShareInProgress">QNearFieldShareTarget::<wbr/>isShareInProgress()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isShareInProgress(){
        return isShareInProgress_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isShareInProgress_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#share-1">QNearFieldShareTarget::<wbr/>share(QList&lt;QFileInfo&gt;)</a></code></p>
     */
    @QtUninvokable
    public final boolean share(java.util.@NonNull Collection<? extends io.qt.core.@NonNull QFileInfo> files){
        return share_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), files);
    }
    
    @QtUninvokable
    private native boolean share_native_cref_QList(long __this__nativeId, java.util.Collection<? extends io.qt.core.QFileInfo> files);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#share">QNearFieldShareTarget::<wbr/>share(QNdefMessage)</a></code></p>
     */
    @QtUninvokable
    public final boolean share(io.qt.nfc.@NonNull QNdefMessage message){
        return share_native_cref_QNdefMessage(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(message));
    }
    
    @QtUninvokable
    private native boolean share_native_cref_QNdefMessage(long __this__nativeId, long message);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareError">QNearFieldShareTarget::<wbr/>shareError()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.nfc.QNearFieldShareManager.@NonNull ShareError shareError(){
        return io.qt.nfc.QNearFieldShareManager.ShareError.resolve(shareError_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int shareError_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qnearfieldsharetarget.html#shareModes">QNearFieldShareTarget::<wbr/>shareModes()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.nfc.QNearFieldShareManager.@NonNull ShareModes shareModes(){
        return new io.qt.nfc.QNearFieldShareManager.ShareModes(shareModes_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int shareModes_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNearFieldShareTarget(QPrivateConstructor p) { super(p); } 
    
}
